unit Main;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, Mask, ToolEdit, RXCtrls, Menus, RxMenus, ExtCtrls;

type
  TMainForm = class(TForm)
    ReplaceButton         : TButton;
    CloseButton           : TButton;
    ViewButton            : TButton;
    SelDirDirectoryEdit   : TDirectoryEdit;
    SelFRxCheckListBox    : TRxCheckListBox;
    SelAllButton          : TButton;
    UnselAllButton        : TButton;
    DebugRxPopupMenu      : TRxPopupMenu;
    DebugPopUpItem        : TMenuItem;
    FullPathPopUpItem     : TMenuItem;
    MessagePopUpItem      : TMenuItem;
    SelDRxLabel           : TRxLabel;
    SelFRxLabel           : TRxLabel;
    ViewAsRadioGroup      : TRadioGroup;
    DelCheckBox           : TCheckBox;
    ViewRxPopupMenu       : TRxPopupMenu;
    View                  : TMenuItem;
    FTypesGroupBox        : TGroupBox;
    HtmCheckBox           : TCheckBox;
    ShtmlCheckBox         : TCheckBox;
    XmlCheckBox           : TCheckBox;
    TxtCheckBox           : TCheckBox;
    RefreshButton         : TButton;
    SourceComboBox        : TComboBox;
    DestinComboBox        : TComboBox;
    RxLabel1              : TRxLabel;
    RxLabel2              : TRxLabel;
    AllCheckBox           : TCheckBox;

    procedure CloseButtonClick           (Sender: TObject);
    procedure FillFileList               (Sender: TObject);
    procedure SelUnselAll                (Sender: TObject);
    procedure DebugRxPopUpMenuSelectItem (Sender: TObject);
    procedure ReplaceSymbol              (Sender: TObject);
    procedure FormCreate                 (Sender: TObject);
    procedure ViewButtonClick            (Sender: TObject);
    procedure SourceComboBoxEnter        (Sender: TObject);
    procedure DestinComboBoxChange       (Sender: TObject);
    procedure AllCheckBoxClick           (Sender: TObject);

  private
    { Private declarations }
  public
    { Public declarations }
  end;

var
  MainForm      : TMainForm;
  DirectoryName : String;
  FileName      : String;
  aFTypes       : array [0..4] of String = ('\*.*','\*.htm','\*.shtml','\*.xml','\*.txt');
  aFTypesChGr   : array [0..4] of TObject ;
  SourceTxt     : String;
  DestinTxt     : String;
implementation

uses
  StrUtils, RxShell, ViewAsText;
{$R *.DFM}

procedure TMainForm.FillFileList(Sender: TObject);
var
  hFile         : THandle;
  FindData      : TWin32FindData;
  LastFile      : Boolean;
  szFullName    : String;
  Counter       : Integer;
  bFound        : Boolean;
  iMinCounter   : Integer;
  iMaxCounter   : Integer;

begin

  SelFRxCheckListBox.Clear;
  DirectoryName := SelDirDirectoryEdit.Text;
  bFound        := False;

  if AllCheckBox.Checked
    then begin
      iMinCounter := 0;
      iMaxCounter := 0;
    end
    else begin
      iMinCounter := 1;
      iMaxCounter := Length (aFTypesChGr)-1;
    end;


  for Counter := iMinCounter to iMaxCounter do
  begin

    if  (aFTypesChGr[Counter] as TCheckBox).Checked = True  then
    begin

      LastFile      := False;
      szFullName    := DirectoryName + aFTypes[Counter];
      hFile         := FindFirstFile(PChar(szFullName),FindData);

      if hFile <> INVALID_HANDLE_VALUE then
      begin

        bFound := True;
        while LastFile=False do
        begin
          FileName := FindData.cFileName;
          if FileName[1] <> '.' then SelFRxCheckListBox.Items.Add(FileName);
          if FindNextFile(hFile,FindData) = False then  LastFile := True;
        end; {while LastFile=False do}

      end ;{if hFile <> INVALID_HANDLE_VALUE then}

    end; {if  (aFTypesChGr[Counter] as TCheckBox).Checked = True}

  end; {for Counter := 0 to 3 do}

  if bFound = False then ShowMessage('Files not found');

end;

procedure TMainForm.SelUnselAll(Sender: TObject);
var
  Counter : Integer;
begin

  if Sender = SelAllButton
  then 
    for Counter := 0 to SelFRxCheckListBox.Items.Count -1  do
      SelFRxCheckListBox.Checked[Counter] := True
  else
    for Counter := 0 to SelFRxCheckListBox.Items.Count -1  do
      SelFRxCheckListBox.Checked[Counter] := False;
end;

procedure TMainForm.CloseButtonClick(Sender: TObject);
begin
  Close;
end;


procedure TMainForm.DebugRxPopUpMenuSelectItem (Sender: TObject);
begin
  
  with  (Sender As TMenuItem) do
  begin
    case Tag  of
      1 : {ShowMessage('Debug'); }
          ReplaceSymbol(Sender As TMenuItem);
      2 : ShowMessage( DirectoryName + '\'+ FileName);
      3 : ShowMessage(#38+'nbsp;');
    else
      ShowMessage('-   debug');
    end; {case Tag  of }
  end;  {with  (Sender As TMenuItem) do}

end;


procedure TMainForm.ReplaceSymbol (Sender: TObject);
var
  szNewName   : String;
  szOldName   : String;
  Counter     : Integer;
  lnFile      : String;
  tfNewFile   : TextFile;
  tfOldFile   : TextFile;
  bReady      : Boolean;          //    

begin

  SourceTxt := SourceComboBox.Text;
  DestinTxt := DestinComboBox.Text;
  bReady    := False;
  
  if SourceTxt = ''
  then ShowMessage('The search string cannot be blank.')
  else if SelFRxCheckListBox.Items.Count = 0
       then ShowMessage('Files not selected')
       else bReady := True;    

  if bReady = False
  then
    ShowMessage('    ')
  else begin

    if Application.MessageBox('Process whith selected files ?','Confirmation',MB_OKCANCEL) = IDOK
    then begin

      for Counter := 0 to SelFRxCheckListBox.Items.Count -1  do
      begin

        if SelFRxCheckListBox.Checked[Counter] = True then
        begin

          szNewName := (DirectoryName + '\'+ SelFRxCheckListBox.Items.Strings[Counter]);
          szOldName := (ExtractFileName(szNewName) + '.rsp');

          CopyFile(PChar(szNewName),PChar(szOldName),True);

          AssignFile(tfNewFile,szNewName);
          ReWrite   (tfNewFile);

          AssignFile(tfOldFile,szOldName);
          Reset     (tfOldFile);

          while not eof(tfOldFile) do
          begin
            ReadLn(tfOldFile,lnFile);
            lnFile:=ReplaceStr(lnFile, SourceTxt, DestinTxt);
            WriteLn(tfNewFile,lnFile);
          end; {while not eof(tfOldFile) do}

          CloseFile(tfOldFile);
          CloseFile(tfNewFile);

          if DelCheckBox.Checked = True then DeleteFile(szOldName);
        end; {if SelFRxCheckListBox.Selected[Counter] = True then}

      end; {for Counter := 0 ... do}

      ShowMessage('Process complete');
    end; {Application.MessageBox([skip]) = IDOK}

  end; {If Ready != 0}
end;


procedure TMainForm.FormCreate(Sender: TObject);
begin

  {View As RadioGroup}
  ViewAsRadioGroup.Items.Add('HTML');
  ViewAsRadioGroup.Items.Add('Text');
  ViewAsRadioGroup.ItemIndex := 0;

  {Files Types CheckBoxGroup}
  aFtypesChGr[0] := AllCheckBox;
  aFTypesChGr[1] := HtmCheckBox;
  aFTypesChGr[2] := ShtmlCheckBox;
  aFTypesChGr[3] := XmlCheckBox;
  aFTypesChGr[4] := TxtCheckBox;
  
end;

procedure TMainForm.ViewButtonClick(Sender: TObject);
var
  Counter : Integer;
begin

  for Counter := 0 to SelFRxCheckListBox.Items.Count -1  do
  begin

    if SelFRxCheckListBox.Selected[Counter] then
    begin

      if ViewAsRadioGroup.Items[ViewAsRadioGroup.ItemIndex] = 'HTML'
        then FileExecute(SelFRxCheckListBox.Items.Strings[Counter],'',DirectoryName,esNormal)
        else
        begin
          ViewAsText.AsTextForm.Caption := 'View As Text : ' +  SelFRxCheckListBox.Items.Strings[Counter];
          with  ViewAsText.AsTextForm.AsTextMemo.Lines do
            LoadFromFile( SelFRxCheckListBox.Items.Strings[Counter]);
           ViewAsText.AsTextForm.ShowModal;
        end;  {if ViewAsRadioGroup.Items[ViewAsRadioGroup.ItemIndex] = 'HTML' else}
      Continue;
      
    end; {if SelFRxCheckListBox.Selected[Counter] then}

  end; {for Counter := 0 to ... do}

end;

procedure TMainForm.SourceComboBoxEnter(Sender: TObject);
begin

   SourceComboBox.Items.Add(SourceComboBox.Text);
end;

procedure TMainForm.DestinComboBoxChange(Sender: TObject);
begin
  DestinComboBox.Items.Add(DestinComboBox.Text);
end;

procedure TMainForm.AllCheckBoxClick(Sender: TObject);
begin

  if AllCheckBox.Checked = True
  then begin
    HtmCheckBox.Enabled   := False;
    ShtmlCheckBox.Enabled := False;
    XmlCheckBox.Enabled   := False;
    TxtCheckBox.Enabled   := False;
  end
  else begin
    HtmCheckBox.Enabled   := True;
    ShtmlCheckBox.Enabled := True;
    XmlCheckBox.Enabled   := True;
    TxtCheckBox.Enabled   := True;
  end;
end;

end.
